##  Transparency and Governance of AI Features
SAP LeanIX follows SAP’s global AI ethics principles and governance framework. SAP provides detailed information about AI model management, data protection and privacy, compliance, and certifications (including applicable regulations and standards) in its central resources:
  * [Responsible AI![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Fproducts%2Fartificial-intelligence%2Fai-ethics.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/products/artificial-intelligence/ai-ethics.html")
  * [SAP Trust Center![Information published on SAP site](https://help.sap.com/doc/72d375467c1e4dcb872dfa2998b6328d/CLOUD/en-US/themes/sap-light/img/sap_link.png)](https://help.sap.com/docs/link-disclaimer?site=https%3A%2F%2Fwww.sap.com%2Fabout%2Ftrust-center.html?locale=en-US&state=PRODUCTION&version=CLOUD "https://www.sap.com/about/trust-center.html")


Workspace data from SAP LeanIX is used only as contextual input to generate AI responses and is not used to train or fine‑tune AI models. Personally identifiable information (PII) such as user names or email addresses is not processed by SAP LeanIX AI capabilities.
In SAP LeanIX, we adhere to the “human-in-the-loop approach.” AI-generated content is clearly indicated with AI icons and labels so that users always know when AI is being used.
